@@ -137,11 +137,19 @@ def main(ctx, project, timeout, verbose):
 
 @main.command("bump", help="Bumps the project version based on the .versions.yml file")
 @click.option("--project", required=False, type=str)
+@click.option(
+    "--version",
+    required=False,
+    type=str,
+    help="Version to apply. If not passed, you will be prompted to insert or select one from a predefined list",
+)
 @click.pass_obj
-def bump(obj, project: Optional[str] = None):
+def bump(obj, project: Optional[str] = None, version: Optional[str] = None):
     from suite_py.commands.bump import Bump
 
-    Bump(obj["project"], obj["config"], obj["tokens"]).run(project=project)
+    Bump(obj["project"], obj["config"], obj["tokens"]).run(
+        project=project, version=version
+    )
 
 
 @main.command(
