@@ -304,7 +304,7 @@ class QA:
                 issues.append(
                     "Qainit is still working on microservices, try again in a while."
                 )
-                issues.append("https://www.youtube.com/watch?v=0ASiDR5Yj0k")
+                issues.append("https://www.youtube.com/watch?v=dQw4w9WgXcQ")
                 return issues
 
             # 3. Check every resource
